Iter

Struct Iter 

pub struct Iter<'a, ThreadState, IterState> { /* private fields */ }
Arguments provided to the iter() closure of a Run.

Implementations

Source

impl<'a, ThreadState, IterState> Iter<'a, ThreadState, IterState>

pub fn meta(&self) -> &'a RunMeta

Returns the RunMeta for the current run.

pub fn thread_state(&self) -> &'a ThreadState

Returns the thread state for the current thread.

pub fn take_iter_state(&mut self) -> IterState

Returns the iteration state for the current iteration, consuming it.

Panics

Panics if the iteration state has already been consumed.

pub fn iter_state(&self) -> &IterState

Returns a reference to the iteration state for the current iteration.

Panics

Panics if the iteration state has already been consumed.