pub struct ConfiguredRun<'a, ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState>where
MeasureOutput: Send + 'static,{ /* private fields */ }Expand description
A fully configured benchmark run, ready to be executed.
Implementations
Sourceimpl<ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState> ConfiguredRun<'_, ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState>where
MeasureOutput: Send + 'static,
impl<ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState> ConfiguredRun<'_, ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState>where
MeasureOutput: Send + 'static,
Sourcepub fn execute_on(
&self,
pool: &mut ThreadPool,
iterations: u64,
) -> RunSummary<MeasureOutput>
pub fn execute_on( &self, pool: &mut ThreadPool, iterations: u64, ) -> RunSummary<MeasureOutput>
Executes the benchmark run on the specified thread pool for a specific number of iterations, returning the result.
If you are executing the benchmark in a Criterion context, you may find it more convenient
to use execute_criterion_on().
Panics
Panics if the thread pool’s processor count is not divisible by the number of groups the run is configured for.
Sourceimpl<ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState> ConfiguredRun<'_, ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState>where
MeasureOutput: Send + 'static,
impl<ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState> ConfiguredRun<'_, ThreadState, IterState, MeasureWrapperState, MeasureOutput, CleanupState>where
MeasureOutput: Send + 'static,
Sourcepub fn execute_criterion_on(
&self,
pool: &mut ThreadPool,
group: &mut BenchmarkGroup<'_, WallTime>,
name: &str,
) -> Vec<MeasureOutput>
Available on crate features criterion only.
pub fn execute_criterion_on( &self, pool: &mut ThreadPool, group: &mut BenchmarkGroup<'_, WallTime>, name: &str, ) -> Vec<MeasureOutput>
criterion only.Executes the benchmark run one or more times as part of a Criterion benchmark group, recording the result with Criterion.
The number of iterations is determined by Criterion and the run is repeated as many times as Criterion decides is appropriate to collect the desired data.
Panics
Panics if the thread pool’s processor count is not divisible by the number of groups the run is configured for.